@@ -10,7 +10,7 @@ use constant _data_code     => 'B';
 my $config = File::ShareDir::Dist::dist_config('FFI-ExtractSymbols');
 
 # ABSTRACT: OpenBSD nm implementation for FFI::ExtractSymbols
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 return 1 if FFI::ExtractSymbols->can('extract_symbols') || $^O ne 'openbsd';
@@ -57,7 +57,7 @@ FFI::ExtractSymbols::OpenBSD - OpenBSD nm implementation for FFI::ExtractSymbols
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
@@ -76,7 +76,11 @@ instead.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Sanko Robinson (SANKO)
 
 =head1 COPYRIGHT AND LICENSE
 
